==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/SwiadczenieWplata.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class SwiadczenieWplata extends GenericDPSObject {
    /**
     * SWIADCZENIE_WPLATA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SWIADCZENIE_WPLATA.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * SWIADCZENIE_WPLATA.ROK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer rok;

    /**
     * SWIADCZENIE_WPLATA.MIESIAC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer miesiac;

    /**
     * SWIADCZENIE_WPLATA.TERMIN_WYPLATY_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long terminWyplatyId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE_WPLATA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SWIADCZENIE_WPLATA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SWIADCZENIE_WPLATA.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * SWIADCZENIE_WPLATA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return SWIADCZENIE_WPLATA.ROK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getRok() {
        return rok;
    }

    /**
     * SWIADCZENIE_WPLATA.ROK
     *
     * @param rok
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRok(Integer rok) {
        this.rok = rok;
    }

    /**
     * @return SWIADCZENIE_WPLATA.MIESIAC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getMiesiac() {
        return miesiac;
    }

    /**
     * SWIADCZENIE_WPLATA.MIESIAC
     *
     * @param miesiac
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMiesiac(Integer miesiac) {
        this.miesiac = miesiac;
    }

    /**
     * @return SWIADCZENIE_WPLATA.TERMIN_WYPLATY_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getTerminWyplatyId() {
        return terminWyplatyId;
    }

    /**
     * SWIADCZENIE_WPLATA.TERMIN_WYPLATY_ID
     *
     * @param terminWyplatyId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTerminWyplatyId(Long terminWyplatyId) {
        this.terminWyplatyId = terminWyplatyId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SwiadczenieWplata other = (SwiadczenieWplata) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getRok() == null ? other.getRok() == null : this.getRok().equals(other.getRok()))
            && (this.getMiesiac() == null ? other.getMiesiac() == null : this.getMiesiac().equals(other.getMiesiac()))
            && (this.getTerminWyplatyId() == null ? other.getTerminWyplatyId() == null : this.getTerminWyplatyId().equals(other.getTerminWyplatyId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getRok() == null) ? 0 : getRok().hashCode());
        result = prime * result + ((getMiesiac() == null) ? 0 : getMiesiac().hashCode());
        result = prime * result + ((getTerminWyplatyId() == null) ? 0 : getTerminWyplatyId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", data=").append(data);
        sb.append(", rok=").append(rok);
        sb.append(", miesiac=").append(miesiac);
        sb.append(", terminWyplatyId=").append(terminWyplatyId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/SwiadczenieWplata.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class SwiadczenieWplata extends GenericDPSObject {
    /**
     * SWIADCZENIE_WPLATA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SWIADCZENIE_WPLATA.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * SWIADCZENIE_WPLATA.ROK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer rok;

    /**
     * SWIADCZENIE_WPLATA.MIESIAC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer miesiac;

    /**
     * SWIADCZENIE_WPLATA.TERMIN_WYPLATY_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long terminWyplatyId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE_WPLATA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SWIADCZENIE_WPLATA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SWIADCZENIE_WPLATA.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * SWIADCZENIE_WPLATA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return SWIADCZENIE_WPLATA.ROK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getRok() {
        return rok;
    }

    /**
     * SWIADCZENIE_WPLATA.ROK
     *
     * @param rok
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRok(Integer rok) {
        this.rok = rok;
    }

    /**
     * @return SWIADCZENIE_WPLATA.MIESIAC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getMiesiac() {
        return miesiac;
    }

    /**
     * SWIADCZENIE_WPLATA.MIESIAC
     *
     * @param miesiac
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMiesiac(Integer miesiac) {
        this.miesiac = miesiac;
    }

    /**
     * @return SWIADCZENIE_WPLATA.TERMIN_WYPLATY_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getTerminWyplatyId() {
        return terminWyplatyId;
    }

    /**
     * SWIADCZENIE_WPLATA.TERMIN_WYPLATY_ID
     *
     * @param terminWyplatyId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTerminWyplatyId(Long terminWyplatyId) {
        this.terminWyplatyId = terminWyplatyId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SwiadczenieWplata other = (SwiadczenieWplata) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getRok() == null ? other.getRok() == null : this.getRok().equals(other.getRok()))
            && (this.getMiesiac() == null ? other.getMiesiac() == null : this.getMiesiac().equals(other.getMiesiac()))
            && (this.getTerminWyplatyId() == null ? other.getTerminWyplatyId() == null : this.getTerminWyplatyId().equals(other.getTerminWyplatyId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getRok() == null) ? 0 : getRok().hashCode());
        result = prime * result + ((getMiesiac() == null) ? 0 : getMiesiac().hashCode());
        result = prime * result + ((getTerminWyplatyId() == null) ? 0 : getTerminWyplatyId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", data=").append(data);
        sb.append(", rok=").append(rok);
        sb.append(", miesiac=").append(miesiac);
        sb.append(", terminWyplatyId=").append(terminWyplatyId);
        sb.append("]");
        return sb.toString();
    }
}
